summaryrefslogtreecommitdiffstats
path: root/librss/article.h
diff options
context:
space:
mode:
Diffstat (limited to 'librss/article.h')
-rw-r--r--librss/article.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/librss/article.h b/librss/article.h
index a05ddb34..0444e7f3 100644
--- a/librss/article.h
+++ b/librss/article.h
@@ -86,7 +86,7 @@ namespace RSS
/**
* RSS 0.90 and upwards
- * @return The headline of this article, or TQString::null if
+ * @return The headline of this article, or TQString() if
* no headline was available.
*/
TQString title() const;
@@ -102,7 +102,7 @@ namespace RSS
/**
* RSS 0.91 and upwards
- * @return A story synopsis, or TQString::null if no description
+ * @return A story synopsis, or TQString() if no description
* was available.
*/
TQString description() const;
@@ -115,7 +115,7 @@ namespace RSS
/**
* RSS 2.0 and upwards
- * @return If this article GUID is permalink. Has no meaning when guid() is TQString::null.
+ * @return If this article GUID is permalink. Has no meaning when guid() is TQString().
*/
bool guidIsPermaLink() const;
@@ -126,7 +126,7 @@ namespace RSS
const TQDateTime &pubDate() const;
/**
* @param parent The parent widget for the KURLLabel.
* @param name A name for the widget which will be used internally.
* @return a widget (a KURLLabel in this case) for the Article.
* This makes building a user-interface which contains the
@@ -139,7 +139,7 @@ namespace RSS
* Note that you have to delete the KURLLabel object returned by
* this method yourself.
*/
- KURLLabel *widget(TQWidget *parent = 0, const char *name = 0) const;
+ KURLLabel *widget(TQWidget *tqparent = 0, const char *name = 0) const;
private:
struct Private;
@@ -126,7 +126,7 @@ namespace RSS
const TQDateTime &pubDate() const;
/**
- * @param parent The parent widget for the KURLLabel.
+ * @param tqparent The tqparent widget for the KURLLabel.
* @param name A name for the widget which will be used internally.
* @return a widget (a KURLLabel in this case) for the Article.